from pathlib import Path
from typing import Optional
from fastapi import FastAPI
from fastapi.staticfiles import StaticFiles
from typer import Typer, Argument
import uvicorn
from anime.routes import router

CURRENT_DIR = Path(__file__).parent
STATIC_DIR = CURRENT_DIR / "static"

cli = Typer()


@cli.command()
def run_app(
    host: str = "0.0.0.0",
    port: int = 8000,
    anime_dir: Optional[Path] = Argument(None, help="Directory where anime is stored."),
):
    app = FastAPI(
        title="Anime Watcher",
        description="API for RCE",
        openapi_url="/api/openapi.json",
        docs_url="/api/docs",
    )
    app.include_router(router, prefix="/api")
    app.mount(
        "/",
        StaticFiles(
            directory=STATIC_DIR,
            html=True,
            check_dir=False,
        ),
    )
    app.state.anime_dir = anime_dir

    uvicorn.run(app, host=host, port=port, workers=1)


def main():
    cli()


if __name__ == "__main__":
    main()
